<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "Destinatari Editați formularul");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "Destinatari Editați formularul");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "formularul Pagina");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "S-ar putea stabili mai mult de un destinatar prin separarea e-mailuri cu virgulă.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "Se salvează ... destinatar");
define('VIEW_FORM_TABLES_HEADING', "Vizualizați tabelele de formular");
define('VIEW_FORM_TABLES_BTN', "Vizualizați tabelele de formular");
define('VIEW_FORM_TABLES_SELECT_TABLE', "Selectați o tabelă pentru vizualizare");
define('VIEW_FORM_TABLES_FILTER_READ', "Filtrați citirea mesajelor");
?>